@@ -1,35 +1,38 @@
 test_that("construction", {
-  df = data.frame(task_id = rep(c("A", "B"), each = 5),
-                  learner_id = paste0("L", 1:5),
+  df = data.frame(task_id = factor(rep(c("A", "B"), each = 5)),
+                  learner_id = factor(paste0("L", 1:5)),
                   RMSE = runif(10))
   expect_silent(BenchmarkAggr$new(df))
   expect_warning(BenchmarkAggr$new(df, independent = FALSE), "independent datasets")
 
   df = data.frame(tasks = rep(c("A", "B"), each = 5),
                   learners = paste0("regr.", 1:5),
-                  regr.rmse = runif(10), stringsAsFactors = FALSE)
+                  regr.rmse = runif(10), stringsAsFactors = TRUE)
   expect_equal(BenchmarkAggr$new(df, task_id = "tasks", learner_id = "learners")$learners,
                as.character(1:5))
   expect_equal(BenchmarkAggr$new(df, task_id = "tasks", learner_id = "learners")$measures, "rmse")
 
   df = data.frame(task_id = rep(c("A", "B"), each = 5),
                   learner_id = paste0("regr.", 1:5),
-                  regr.rmse = runif(10), stringsAsFactors = FALSE)
-  expect_equal(BenchmarkAggr$new(df, strip_prefix = FALSE)$learners, unique(df$learner_id))
+                  regr.rmse = runif(10), stringsAsFactors = TRUE)
+  expect_equal(BenchmarkAggr$new(df, strip_prefix = FALSE)$learners, as.character(unique(df$learner_id)))
   expect_equal(BenchmarkAggr$new(df, strip_prefix = FALSE)$measures, "regr.rmse")
 
   df = data.frame(task_id = rep(c("A", "B"), each = 5),
-                  learner_id = paste0("L", 1:5))
+                  learner_id = paste0("L", 1:5),
+                  stringsAsFactors = TRUE)
   expect_error(BenchmarkAggr$new(df), "At least one")
 
   df = data.frame(task_id = rep(c("A"), each = 5),
                   learner_id = paste0("L", 1:5),
-                  RMSE = runif(5))
+                  RMSE = runif(5),
+                  stringsAsFactors = TRUE)
   expect_warning(as.BenchmarkAggr(df), "multiple tasks")
 
   df = data.frame(task_id = rep(c("A", "B"), each = 5),
                   learner_id = paste0("L", 1:5),
-                  RMSE = runif(20))
+                  RMSE = runif(20),
+                  stringsAsFactors = TRUE)
   expect_error(as.BenchmarkAggr(df), "combination")
 })
 
@@ -39,7 +42,8 @@ test_that("public methods", {
   mse = rmse^2
   df = data.frame(tasks = rep(c("A", "B"), each = 5),
                   learners = paste0("L", 1:5),
-                  RMSE = rmse, MSE = mse)
+                  RMSE = rmse, MSE = mse,
+                  stringsAsFactors = TRUE)
   ba = BenchmarkAggr$new(df, task_id = "tasks", learner_id = "learners")
   expect_output(print(ba), "10 rows with 2 tasks, 5 learners and 2 measures")
   expect_output(ba$summary(), "10 rows with 2 tasks, 5 learners and 2 measures")
@@ -69,7 +73,8 @@ test_that("public methods", {
 test_that("active bindings", {
   df = data.frame(task_id = rep(c("A", "B"), each = 5),
                   learner_id = paste0("L", 1:5),
-                  RMSE = round(runif(10, 1, 5)))
+                  RMSE = round(runif(10, 1, 5)),
+                  stringsAsFactors = TRUE)
   ba = BenchmarkAggr$new(df)
   expect_equal(class(ba$data)[1], "data.table")
   expect_equal(ba$learners, paste0("L", 1:5))
@@ -92,6 +97,8 @@ test_that("mlr3 coercions", {
   expect_equal(class(as.BenchmarkAggr(bm))[1], "BenchmarkAggr")
   expect_equal(class(as.BenchmarkAggr(bm, meas = msr("regr.mae")))[1], "BenchmarkAggr")
   aggr = bm$aggregate(msrs(c("regr.rmse", "regr.mae")))
+  aggr$task_id = factor(aggr$task_id)
+  aggr$learner_id = factor(aggr$learner_id)
   ba = BenchmarkAggr$new(aggr)
   expect_equal(class(as.BenchmarkAggr(bm))[1], "BenchmarkAggr")
   expect_equal(ba$measures, c("rmse", "mae"))
